## 0.0.5

This new version introduces the QueryBot prototype and its corresponding tests. It also includes improvements in documentation and example notebooks. The version also includes some housekeeping changes like ignoring certain files and directories.

### New Features

- QueryBot prototype added to the project. This is a new feature that allows users to interact with the bot using queries. (c190e03) (Eric Ma)
- Tests for QueryBot have been added to ensure its proper functioning. (78a791d) (Eric Ma)
- A new example on how to build a simple panel app has been added. This will help users understand how to create their own apps. (7e928b7) (Eric Ma)
- A notebook chatbot example has been added to provide a practical example of how to use the chatbot in a notebook environment. (7e96304) (Eric Ma)
- A simplebot notebook has been added to the project. This notebook provides a simple example of a bot. (0121db5) (Eric Ma)

### Bug Fixes

- The chat notebook example is now properly executed. This fix ensures that the example runs as expected. (60803dd) (Eric Ma)

### Deprecations

- Notebook execution has been disabled. This change is made to prevent automatic execution of notebooks. (89c39c1) (Eric Ma)

### Other Changes

- The project version has been bumped from 0.0.4 to 0.0.5. (e94a28) (Eric Ma)
- Docstrings have been added to the project for better code understanding and readability. (2eb8c62) (Eric Ma)
- The directory 'data/' is now ignored by Git. This prevents unnecessary tracking of changes in this directory. (4252cd4) (Eric Ma)
- The 'mknotebooks' has been moved to the pip section. (e5f0e9d) (Eric Ma)
- Temporary markdown files created by 'mknotebooks' are now ignored by Git. This prevents unnecessary tracking of these temporary files. (1e4821d) (Eric Ma)
- The README file has been updated twice to provide the latest information about the project. (b3e02e2, 32f32db) (Eric Ma)
